#!/usr/bin/env perl -w
use strict;
use Test;
BEGIN { plan tests => 1 }

use Mail::Ezmlm::Archive; ok(1);
exit;
__END__
